#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.assembly_interfaces.assembly_feature import AssemblyFeature
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.limit import Limit
from pycatia.product_structure_interfaces.product import Product
from pycatia.sketcher_interfaces.sketch import Sketch


class AssemblyHole(AssemblyFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAssemblyInterfaces.AssemblyFeature
                |                         AssemblyHole
                | 
                | Represents the AssemblyHole object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_hole = com_object

    @property
    def anchor_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnchorMode() As CatHoleAnchorMode
                | 
                |     Returns or sets the hole anchor mode.
                |     This property is valid when the hole type is Counterbored or
                |     Counterdrilled.
                | 
                |     Example:
                |         The following example saves in holeAnchorMode the anchor mode of the
                |         hole assemblyHole and sets it so that the anchor mode will now be set to the
                |         middle of its head.
                | 
                |          Dim holeAnchorMode
                |          Set holeAnchorMode = assemblyHole.AnchorMode
                |          assemblyHole.AnchorMode = catMiddlePointHoleAnchor

        :return: enum cat_hole_anchor_mode
        :rtype: int
        """

        return self.assembly_hole.AnchorMode

    @anchor_mode.setter
    def anchor_mode(self, value: int):
        """
        :param int value: enum cat_hole_anchor_mode
        """

        self.assembly_hole.AnchorMode = value

    @property
    def bottom_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BottomAngle() As Angle (Read Only)
                | 
                |     Returns the hole bottom angle.
                |     This property is valid when the hole bottom type is VBottom. The hole
                |     bottom angle is returned as a Angle object.
                | 
                |     Example:
                |         The following example retrieves in holeBottomAngle the bottom angle of
                |         the hole assemblyHole.
                | 
                |          Dim holeBottomAngle As Angle
                |          Set holeBottomAngle = assemblyHole.BottomAngle

        :rtype: Angle
        """

        return Angle(self.assembly_hole.BottomAngle)

    @property
    def bottom_limit(self) -> Limit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BottomLimit() As Limit (Read Only)
                | 
                |     Returns the hole bottom limit.
                |     This limit manages the way the hole is ended. It is returned as a Limit
                |     object.
                | 
                |     Example:
                |         The following example retrieves in limit the bottom limit of the hole
                |         assemblyHole.
                | 
                |          Dim limit As Limit
                |          Set limit = assemblyHole.BottomLimit

        :rtype: Limit
        """

        return Limit(self.assembly_hole.BottomLimit)

    @property
    def bottom_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BottomType() As CatHoleBottomType
                | 
                |     Returns or sets the hole bottom type.
                | 
                |     Example:
                |         The following example saves in holeBottomType the bottom type of the
                |         hole assemblyHole and sets it so that the bottom will now be a V-like
                |         one.
                | 
                |          Dim holeBottomType
                |          Set holeBottomType = assemblyHole.BottomType
                |          assemblyHole.BottomType = catVHoleBottom

        :return: enum cat_hole_bottom_type
        :rtype: int
        """

        return self.assembly_hole.BottomType

    @bottom_type.setter
    def bottom_type(self, value: int):
        """
        :param int value: enum cat_hole_bottom_type
        """

        self.assembly_hole.BottomType = value

    @property
    def diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Diameter() As Length (Read Only)
                | 
                |     Returns the hole diameter.
                |     It is returned as a Length object.
                | 
                |     Example:
                |         The following example retrieves in holeDiam the diameter of the hole
                |         assemblyHole.
                | 
                |          Dim holeDiam As Length
                |          Set holeDiam = assemblyHole.Diameter

        :rtype: Length
        """

        return Length(self.assembly_hole.Diameter)

    @property
    def head_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HeadAngle() As Angle (Read Only)
                | 
                |     Returns the hole head angle.
                |     This property is valid when the hole type is Tapered, Counterdrilled or
                |     Countersunk. The hole head angle is returned as a Angle
                |     object.
                | 
                |     Example:
                |         The following example retrieves in holeHeadAngle the head angle of the
                |         hole assemblyHole.
                | 
                |          Dim holeHeadAngle As Angle
                |          Set holeHeadAngle = assemblyHole.HeadAngle

        :rtype: Angle
        """

        return Angle(self.assembly_hole.HeadAngle)

    @property
    def head_depth(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HeadDepth() As Length (Read Only)
                | 
                |     Returns the hole head depth.
                |     This property is valid when the hole type is Counterbored, Counterdrilled
                |     or Countersunk. The hole head depth is returned as a Length
                |     object.
                | 
                |     Example:
                |         The following example retrieves in holeHeadDepth the head depth of the
                |         hole assemblyHole.
                | 
                |          Dim holeHeadDepth As Length
                |          Set holeHeadDepth = assemblyHole.HeadDepth

        :rtype: Length
        """

        return Length(self.assembly_hole.HeadDepth)

    @property
    def head_diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HeadDiameter() As Length (Read Only)
                | 
                |     Returns the hole head diameter.
                |     This property is valid when the hole type is Counterbored or
                |     Counterdrilled. The hole head diameter is returned as a Length
                |     object.
                | 
                |     Example:
                |         The following example retrieves in holeHeadDiam the head diameter of
                |         the hole assemblyHole.
                | 
                |          Dim holeHeadDiam As Length
                |          Set holeHeadDiam = assemblyHole.HeadDiameter

        :rtype: Length
        """

        return Length(self.assembly_hole.HeadDiameter)

    @property
    def sketch(self) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Sketch() As Sketch (Read Only)
                | 
                |     Returns the hole positioning sketch.
                | 
                |     Example:
                |         The following example retrieves in sketch the positioning sketch of the
                |         hole assemblyHole.
                | 
                |          Dim sketch As Sketch
                |          Set sketch = assemblyHole.Sketch

        :rtype: Sketch
        """

        return Sketch(self.assembly_hole.Sketch)

    @property
    def sketch_component(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SketchComponent() As Product (Read Only)
                | 
                |     Returns the component containing the hole positioning
                |     sketch.
                | 
                |     Example:
                |         The following example retrieves in skComp the component that contains
                |         the positioning sketch of the hole assemblyHole.
                | 
                |          Dim skComp As Product
                |          Set skComp = assemblyHole.SketchComponent

        :rtype: Product
        """

        return Product(self.assembly_hole.SketchComponent)

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As CatHoleType
                | 
                |     Returns or sets the hole type.
                | 
                |     Example:
                |         The following example saves in holeType the type of the hole
                |         assemblyHole, and then sets it so that it will now be a tapered
                |         hole.
                | 
                |          Set holeType = assemblyHole.Type
                |          assemblyHole.Type = catTaperedHole

        :return: enum cat_hole_type
        :rtype: int
        """

        return self.assembly_hole.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value: enum cat_hole_type
        """

        self.assembly_hole.Type = value

    def get_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDirection(CATSafeArrayVariant ioDirection)
                | 
                |     Retrieves the hole direction vector components.
                |     These components are expressed in millimeter according to the absolute
                |     coordinate system.
                | 
                |     Parameters:
                | 
                |         ioDirection
                |             The direction vector components, as a safe array made up of three
                |             doubles: X, Y, Z
                |             The array must be previously initialized. 
                | 
                |     Example:
                |         The following example returns in dirArray the direction vector
                |         components of the hole assemblyHole.
                | 
                |          Dim dirArray(2)
                |          Call assemblyHole.GetDirection(dirArray)
                |          Set x = dirArray[0]
                |          Set y = dirArray[1]
                |          Set z = dirArray[2]

        :param tuple io_direction:
        :rtype: None
        """
        return self.assembly_hole.GetDirection()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(assembly_hole)
        # #     Dim ioDirection (2)
        # #     assembly_hole.GetDirection ioDirection
        # #     get_direction = ioDirection
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOrigin(CATSafeArrayVariant ioOrigin)
                | 
                |     Retrieves the origin point to which the hole is anchored.
                |     This point belongs to a plane tangent to the hole. The coordinates are
                |     expressed in millimeter according to the absolute coordinate
                |     system.
                | 
                |     Parameters:
                | 
                |         ioOrigin
                |             The hole origin point coordinates, as a safe array made up of three
                |             doubles: X, Y, Z
                |             The array must be previously initialized. 
                | 
                |     Example:
                |         The following example returns in coordArray the coordinates of the hole
                |         assemblyHole.
                | 
                |          Dim coordArray(2)
                |          Call assemblyHole.GetOrigin coordArray
                |          Set x = coordArray[0]
                |          Set y = coordArray[1]
                |          Set z = coordArray[2]

        :param tuple io_origin:
        :rtype: None
        """
        return self.assembly_hole.GetOrigin()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(assembly_hole)
        # #     Dim ioOrigin (2)
        # #     assembly_hole.GetOrigin ioOrigin
        # #     get_origin = ioOrigin
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_direction(self, i_line: Reference, i_line_comp: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDirection(Reference iLine,
                | Product iLineComp)
                | 
                |     Sets the hole axis direction.
                | 
                |     Parameters:
                | 
                |         iLine
                |             The hole axis direction, as a reference to a line or an edge.
                |             
                |         iLineComp
                |             The component containing the axis direction 
                | 
                |     Example:
                |         The following example sets the axis direction of the hole assemblyHole
                |         with the dirRef line of the component dirComp.
                | 
                |          assemblyHole.SetDirection dirRef, dirComp

        :param Reference i_line:
        :param Product i_line_comp:
        :rtype: None
        """
        return self.assembly_hole.SetDirection(i_line.com_object, i_line_comp.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_direction'
        # # vba_code = """
        # # Public Function set_direction(assembly_hole)
        # #     Dim iLine (2)
        # #     assembly_hole.SetDirection iLine
        # #     set_direction = iLine
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblyHole(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.osm_interfaces.scene import Scene
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.collection import Collection


class Scenes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Scenes
                | 
                | A collection of scenes contained in a given ProductDocument.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.scenes = com_object

    def add_copy_scene(self, i_name: str, i_reference_scene: Scene) -> Scene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddCopyScene(CATBSTR iName,
                | Scene iReferenceScene) As Scene
                | 
                |     Creates a scene from another and adds it to the Scenes
                |     collection.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the scene 
                |         iReferenceScene
                |             The scene to be copied 
                | 
                |     Returns:
                |         The created scene 
                |     Example:
                | 
                |              This example creates the Engine scene from the SpareWheel
                |              scene
                |             and adds the scene to the ToolKits collection.
                |
                |             Dim Engine As Scene
                |             Set Engine = ToolKits.AddNewScene("Engine", SpareWheel)

        :param str i_name:
        :param Scene i_reference_scene:
        :rtype: Scene
        """
        return Scene(self.scenes.AddCopyScene(i_name, i_reference_scene.com_object))

    def add_new_scene(self, i_name: str, i_reference_product: Product) -> Scene:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddNewScene(CATBSTR iName,
                | Product iReferenceProduct) As Scene
                | 
                |     Creates a scene from a product and adds it to the Scenes
                |     collection.
                | 
                |     Parameters:
                | 
                |         iName
                |             The name of the scene 
                |         iReferenceProduct
                |             The product used as reference 
                | 
                |     Returns:
                |         The created scene 
                |     Example:
                | 
                |              This example creates the SpareWheel scene from the reference
                |              product
                |             FrontRightWheel and adds the scene to the ToolKits
                |             collection.
                |
                |             Dim SpareWheel As Scene
                |             Set SpareWheel = ToolKits.AddNewScene("SpareWheel", FrontRightWheel)

        :param str i_name:
        :param Product i_reference_product:
        :rtype: Scene
        """
        return Scene(self.scenes.AddNewScene(i_name, i_reference_product.com_object))

    def remove(self, i_scene: Scene) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(Scene iScene)
                | 
                |     Removes a scene from the Scenes collection.
                | 
                |     Parameters:
                | 
                |         iScene
                |             The scene to remove. 
                | 
                |     Example:
                | 
                |              This example removes the Engine scene from the ToolKits
                |              collection.
                |
                |             ToolKits.Remove Engine

        :param Scene i_scene:
        :rtype: None
        """
        return self.scenes.Remove(i_scene.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(scenes)
        # #     Dim iScene (2)
        # #     scenes.Remove iScene
        # #     remove = iScene
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Scenes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingUserRepresentation(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingUserRepresentation
                | 
                | Interface dedicated to objects representation management.
                | Role: This interface offers services to manage mainly the user
                | representation.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_user_representation = com_object

    def set_representation(self, i_path_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRepresentation(CATBSTR iPathName)
                | 
                |     Sets the User Representation Associated to the Object.
                | 
                |     Parameters:
                | 
                |         iPathName
                |             The complete absolute path name to the External
                |             Object

        :param str i_path_name:
        :rtype: None
        """
        return self.manufacturing_user_representation.SetRepresentation(i_path_name)

    def __repr__(self):
        return f'ManufacturingUserRepresentation(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.drafting_interfaces.drawing_text import DrawingText
from pycatia.system_interfaces.collection import Collection


class DrawingTexts(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingTexts
                | 
                | A collection of all the drawing texts currently managed by a drawing view of
                | drawing sheet in a drawing document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingText)
        self.drawing_texts = com_object
        self.child_object = DrawingText

    def add(self, i_drawing_text: str, i_position_x: float, i_position_y: float) -> DrawingText:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR iDrawingText,
                | double iPositionX,
                | double iPositionY) As DrawingText
                | 
                |     Creates a drawing text and adds it to the DrawingTexts
                |     collection.
                | 
                |     Parameters:
                | 
                |         iDrawingText
                |             The character string that makes up the drawing text to create
                |             
                |         iPositionX,iPositionY
                |             The drawing text x and y coordinates, expressed in millimeters,
                |             with respect to the drawing view coordinate system
                |             
                | 
                |     Returns:
                |         The created drawing text 
                | 
                | Example:
                |     The following example creates a drawing text with the string ComplexText
                |     and retrieved in MyText in the drawing view collection of the MyView drawing
                |     view. This view belongs to the drawing view collection of the drawing
                |     sheet
                | 
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim MyText As DrawingText
                |      Set MyText = MyView.Texts.Add("ComplexText", 0., 0.)

        :param str i_drawing_text:
        :param float i_position_x:
        :param float i_position_y:
        :rtype: DrawingText
        """
        return DrawingText(self.drawing_texts.Add(i_drawing_text, i_position_x, i_position_y))

    def item(self, i_index: int) -> DrawingText:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(long iIndex) As DrawingText
                | 
                |     Returns a drawing text using its index from the DrawingTexts
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing text to retrieve from the collection of
                |             drawing texts. As a numerics, this index is the rank of the drawing text in the
                |             collection. The index of the first drawing text in the collection is 1, and the
                |             index of the last drawing text is Count. 
                | 
                |     Returns:
                |         The retrieved drawing view 
                |     Example:
                |         This example retrieves in ThisDrawingText the second drawing text, in
                |         the drawing view collection of the active view in the active sheet, in the
                |         active document supposed to be a drawing document.
                | 
                |          Dim MyView  As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          Dim ThisDrawingText As DrawingText
                |          Set ThisDrawingText = MyView.Texts.Item(2)

        :param int i_index:
        :rtype: DrawingText
        """
        return DrawingText(self.drawing_texts.Item(i_index))

    def remove(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(long iIndex)
                | 
                |     Removes a drawing text from the DrawingTexts collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing text to remove from the collection of
                |             drawing texts. As a numerics, this index is the rank of the drawing text in the
                |             collection. The index of the first drawing text in the collection is 1, and the
                |             index of the last drawing text is Count. 
                | 
                |     Example:
                |         The following example removes the third drawing text in the drawing
                |         text collection of the active view of the active document, supposed to be a
                |         drawing document.
                | 
                |          Dim MyView As DrawingView
                |          Set MyView  = MySheet.Views.ActiveView
                |          MyView.DrawingTexts.Remove(3)

        :param int i_index:
        :rtype: None
        """
        return self.drawing_texts.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingText:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingText(self.drawing_texts.Item(n + 1))

    def __iter__(self) -> Iterator[DrawingText]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'DrawingTexts(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.system_interfaces.any_object import AnyObject


class SchCompConnector(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchCompConnector
                | 
                | Manage the connectors of a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_comp_connector = com_object

    def add_connector(
            self,
            i_class_type: str,
            i_grr: SchGRRComp,
            i_db2_cntr_position: tuple,
            o_new_sch_cntr: SchAppConnector
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddConnector(CATBSTR iClassType,
                | SchGRRComp iGRR,
                | CATSafeArrayVariant iDb2CntrPosition,
                | SchAppConnector oNewSchCntr)
                | 
                |     Add a connector.
                | 
                |     Parameters:
                | 
                |         iClassType
                |             Class type of the connector to be added. 
                |         iGRR
                |             The graphical image of the component to add the connector to. If
                |             NULL, connector will be added to all representations.
                |             
                |         iDb2CntrPosition
                |             The position of the connector (optional, it could be NULL).
                |             
                |         oNewSchCntr
                |             The new Schematic Connector object created. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompConnector
                |          Dim strVar1 As String
                |          Dim objArg2 As SchGRRComp
                |          Dim dbVar3(2) As CATSafeArrayVariant
                |          Dim objArg4 As SchAppConnector
                |           ...
                |         
                |         objThisIntf.AddConnectorstrVar1,objArg2,dbVar3,objArg4

        :param str i_class_type:
        :param SchGRRComp i_grr:
        :param tuple i_db2_cntr_position:
        :param SchAppConnector o_new_sch_cntr:
        :rtype: tuple
        """
        return self.sch_comp_connector.AddConnector(
            i_class_type,
            i_grr.com_object,
            i_db2_cntr_position,
            o_new_sch_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_connector'
        # # vba_code = """
        # # Public Function add_connector(sch_comp_connector)
        # #     Dim iClassType (2)
        # #     sch_comp_connector.AddConnector iClassType
        # #     add_connector = iClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_dynamic_connector(
            self,
            i_class_type: str,
            i_grr: SchGRRComp,
            i_db2_cntr_position: tuple,
            o_new_sch_cntr: SchAppConnector
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddDynamicConnector(CATBSTR iClassType,
                | SchGRRComp iGRR,
                | CATSafeArrayVariant iDb2CntrPosition,
                | SchAppConnector oNewSchCntr)
                | 
                |     Add a dynamic connector.
                | 
                |     Parameters:
                | 
                |         iClassType
                |             Class type of the connector to be added. 
                |         iGRR
                |             The graphical image of the component to add the connector to. If
                |             NULL, connector will be added to all representations.
                |             
                |         iDb2CntrPosition
                |             The position of the connector (optional, it could be NULL).
                |             
                |         oNewSchCntr
                |             The new Schematic Connector object created. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchCompConnector
                |          Dim strVar1 As String
                |          Dim objArg2 As SchGRRComp
                |          Dim dbVar3(2) As CATSafeArrayVariant
                |          Dim objArg4 As SchAppConnector
                |           ...
                |          objThisIntf.AddDynamicConnectorstrVar1,objArg2,dbVar3,objArg4

        :param str i_class_type:
        :param SchGRRComp i_grr:
        :param tuple i_db2_cntr_position:
        :param SchAppConnector o_new_sch_cntr:
        :rtype: tuple
        """
        return self.sch_comp_connector.AddDynamicConnector(
            i_class_type,
            i_grr.com_object,
            i_db2_cntr_position,
            o_new_sch_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_dynamic_connector'
        # # vba_code = """
        # # Public Function add_dynamic_connector(sch_comp_connector)
        # #     Dim iClassType (2)
        # #     sch_comp_connector.AddDynamicConnector iClassType
        # #     add_dynamic_connector = iClassType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_connector(self, i_grr: SchGRRComp, i_cntr_to_remove: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveConnector(SchGRRComp iGRR,
                | SchAppConnector iCntrToRemove)
                | 
                |     Remove a connector.
                | 
                |     Parameters:
                | 
                |         iCntrToRemove
                |             The schematic connector object to be removed 
                |         iGRR
                |             The graphical image of the component to remove the connector from.
                |             If NULL, connector will be removed from all representations.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchCompConnector
                |          Dim objArg1 As SchGRRComp
                |          Dim objArg2 As SchAppConnector
                |           ...
                |          objThisIntf.RemoveConnectorobjArg1,objArg2

        :param SchGRRComp i_grr:
        :param SchAppConnector i_cntr_to_remove:
        :rtype: None
        """
        return self.sch_comp_connector.RemoveConnector(i_grr.com_object, i_cntr_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_connector'
        # # vba_code = """
        # # Public Function remove_connector(sch_comp_connector)
        # #     Dim iGRR (2)
        # #     sch_comp_connector.RemoveConnector iGRR
        # #     remove_connector = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchCompConnector(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_step import ABQStep
from pycatia.system_interfaces.any_object import AnyObject


class ABQJob(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQJob
                | 
                | Represents an Abaqus job (ABQJob) object.
                | Role: Access an Abaqus job object or determine its properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_job = com_object

    @property
    def computation_dir(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ComputationDir() As CATBSTR
                | 
                |     Sets or returns the computation directory.
                | 
                |     Returns:
                |         The computation directory.
                | 
                |         Example:
                |             This example sets the computation directory for the myJob job to
                |             "D:\\CompDir".
                | 
                |              myJob.ComputationDir = "D:\\CompDir"

        :rtype: str
        """

        return self.abq_job.ComputationDir

    @computation_dir.setter
    def computation_dir(self, value: str):
        """
        :param str value:
        """

        self.abq_job.ComputationDir = value

    @property
    def contact_print(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactPrint() As boolean
                | 
                |     Returns or sets whether contact constraint data are
                |     printed.
                | 
                |     Returns:
                |         A boolean specifying whether contact constraint data will be
                |         printed.
                | 
                |         Example:
                |             This example sets the printing of contact constraint data for the
                |             myJob job to False.
                | 
                |              myJob.ContactPrint = False

        :rtype: bool
        """

        return self.abq_job.ContactPrint

    @contact_print.setter
    def contact_print(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.ContactPrint = value

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Returns or sets the job description.
                | 
                |     Example:
                |         This example sets the job description for the myJob job to
                |         "AutomatedJob".
                | 
                |          myJob.Description = "AutomatedJob"

        :rtype: str
        """

        return self.abq_job.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_job.Description = value

    @property
    def echo_print(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EchoPrint() As boolean
                | 
                |     Sets or returns whether an echo of the input data is
                |     printed.
                | 
                |     Returns:
                |         A boolen specifying whether the input data will be
                |         printed.
                | 
                |         Example:
                |             This example sets the printing of echo of the input data for the
                |             myJob job to True.
                | 
                |              myJob.EchoPrint = True

        :rtype: bool
        """

        return self.abq_job.EchoPrint

    @echo_print.setter
    def echo_print(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.EchoPrint = value

    @property
    def history_print(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HistoryPrint() As boolean
                | 
                |     Sets or returns whether history data are printed.
                | 
                |     Returns:
                |         A boolean specifying whether the the history data will be
                |         printed.
                | 
                |         Example:
                |             This example sets the printing of history data for the myJob job to
                |             True.
                | 
                |              myJob.HistoryPrint = True

        :rtype: bool
        """

        return self.abq_job.HistoryPrint

    @history_print.setter
    def history_print(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.HistoryPrint = value

    @property
    def input_file_format(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InputFileFormat() As boolean
                | 
                |     Sets or returns the format of the input file generated by the
                |     job.
                | 
                |     Returns:
                |         The input file format.
                | 
                |           
                |         Legal values:
                |          False (an assembly of separate parts)
                |          True  (a single part)
                |          
                | 
                |         Example:
                |             This example sets the input file format for the myJob job to a
                |             single part.
                | 
                |              myJob.InputFileFormat = True

        :rtype: bool
        """

        return self.abq_job.InputFileFormat

    @input_file_format.setter
    def input_file_format(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.InputFileFormat = value

    @property
    def max_memory(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxMemory() As double
                | 
                |     Sets or returns the amount of memory (in percent or MB) available to the
                |     solver
                | 
                |     Returns:
                |         The amount of memory.
                | 
                |         Example:
                |             This example sets the amount of memory available to the solver for
                |             myJob job to 60.
                | 
                |              myJob.MaxMemory = 60

        :rtype: float
        """

        return self.abq_job.MaxMemory

    @max_memory.setter
    def max_memory(self, value: float):
        """
        :param float value:
        """

        self.abq_job.MaxMemory = value

    @property
    def memory_unit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MemoryUnit() As MemoryUnit_Type
                | 
                |     Sets or returns the units to be used for specifying the maximum memory to
                |     be used by the solver.
                | 
                |     Returns:
                |         The unit.
                |
                |         Legal values:
                |          PERCENT
                |          MEGABYTES
                |
                |         Example:
                |             This example sets the unit for the myJob job to
                |             PERCENT.
                | 
                |              myJob.MemoryUnit = PERCENT

        :return: enum memory_unit_type
        :rtype: int
        """

        return self.abq_job.MemoryUnit

    @memory_unit.setter
    def memory_unit(self, value: int):
        """
        :param int value: enum memory_unit_type
        """

        self.abq_job.MemoryUnit = value

    @property
    def model_consistency_check(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ModelConsistencyCheck() As boolean
                | 
                |     Sets or returns whether a model consistency check should be
                |     performed.
                | 
                |     Returns:
                |         A boolean specifying whether a consistency check will be
                |         performed.
                | 
                |         Example:
                |             This example sets the Model consistency check for the myJob job to
                |             False.
                | 
                |              myJob.ModelConsistencyCheck = False

        :rtype: bool
        """

        return self.abq_job.ModelConsistencyCheck

    @model_consistency_check.setter
    def model_consistency_check(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.ModelConsistencyCheck = value

    @property
    def model_print(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ModelPrint() As boolean
                | 
                |     Sets or returns or sets whether model definition data is
                |     printed.
                | 
                |     Returns:
                |         A boolean specifying whether the model definition data will be
                |         printed.
                | 
                |         Example:
                |             This example sets the printing of model definition data for the
                |             myJob job to False.
                | 
                |              myJob.ModelPrint = False

        :rtype: bool
        """

        return self.abq_job.ModelPrint

    @model_print.setter
    def model_print(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.ModelPrint = value

    @property
    def num_cpus(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumCpus() As short
                | 
                |     Sets or returns the number of CPUs to use for this
                |     analysis.
                | 
                |     Returns:
                |         The number of CPUs.
                | 
                |         Example:
                |             This example sets the number of CPUs to use myJob job to
                |             3.
                | 
                |              myJob.NumCpus = 3

        :rtype: int
        """

        return self.abq_job.NumCpus

    @num_cpus.setter
    def num_cpus(self, value: int):
        """
        :param int value:
        """

        self.abq_job.NumCpus = value

    @property
    def parallelization_method_standard(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ParallelizationMethodStandard() As
                | ParallelMethodStd_Type
                | 
                |     Sets or returns the parallelization method for the Abaqus/Standard direct
                |     solver.
                | 
                |     Returns:
                |         The parallelization method.
                | 
                |           
                |         Legal values:
                |          TREE 
                |          SUPERNODE
                |          
                | 
                |         Example:
                |             This example sets the parallelization method for the myJob job to
                |             TREE.
                | 
                |              myJob.ParallelizationMethodStandard = TREE

        :return: enum parallel_method_std_type
        :rtype: int
        """

        return self.abq_job.ParallelizationMethodStandard

    @parallelization_method_standard.setter
    def parallelization_method_standard(self, value: int):
        """
        :param int value: enum parallel_method_std_type
        """

        self.abq_job.ParallelizationMethodStandard = value

    @property
    def restart_read_interval(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartReadInterval() As short
                | 
                |     Sets or returns the interval of restart read requests. This is only valid
                |     if RestartReadOption is RESTART_INTERVAL The value must be greater than
                |     0.
                | 
                |     Returns:
                |         The interval of restart read requests.
                | 
                |         Example:
                |             This example sets the restart read request interval for myJob job
                |             to 10.
                | 
                |              myJob.RestartReadInterval = 10

        :rtype: int
        """

        return self.abq_job.RestartReadInterval

    @restart_read_interval.setter
    def restart_read_interval(self, value: int):
        """
        :param int value:
        """

        self.abq_job.RestartReadInterval = value

    @property
    def restart_read_job(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartReadJob() As CATBSTR
                | 
                |     Sets or returns or the path to the original job (\\*.odb)
                |     file.
                | 
                |     Returns:
                |         The path to the original job (\\*.odb) file.
                |
                |         Example:
                |             This example sets the original job for the myJob job to
                |             "D:\\myoriginaljob.odb".
                | 
                |              myJob.RestartReadJob = "D:\\myoriginaljob.odb"

        :rtype: str
        """

        return self.abq_job.RestartReadJob

    @restart_read_job.setter
    def restart_read_job(self, value: str):
        """
        :param str value:
        """

        self.abq_job.RestartReadJob = value

    @property
    def restart_read_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartReadOption() As short
                | 
                |     Sets or returns the restart read option. This is only valid if
                |     RestartReadOption is ABQ_STEP_OBJECT
                | 
                |     Returns:
                |         The option of restart read requests.
                | 
                |           
                |         Legal values:
                |          ABQ_RESTART_END_OF_STEP - The current step is terminated from which
                |          restart  
                |          is being made and restarts from end of that
                |         step.
                |          ABQ_RESTART_INTERVAL- Analysis will restart from the specified
                |          interval
                |                             number within the specified step.
                |          
                | 
                |         Example:
                |             This example sets the restart read option for myJob job to end of
                |             step.
                | 
                |              myJob.RestartReadOption = ABQ_RESTART_END_OF_STEP

        :return: enum abq_restart_read_option
        :rtype: int
        """

        return self.abq_job.RestartReadOption

    @restart_read_option.setter
    def restart_read_option(self, value: int):
        """
        :param int value: enum abq_restart_read_option
        """

        self.abq_job.RestartReadOption = value

    @property
    def restart_read_step(self) -> ABQStep:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartReadStep() As ABQStep
                | 
                |     Sets or returns the Step.
                | 
                |     Returns:
                |         The Step of restart read requests.
                | 
                |         Example:
                |             This example sets the step for myJob job to 2.
                | 
                |              myJob.RestartReadStep = 2

        :rtype: ABQStep
        """

        return ABQStep(self.abq_job.RestartReadStep)

    @restart_read_step.setter
    def restart_read_step(self, value: ABQStep):
        """
        :param ABQStep value:
        """

        self.abq_job.RestartReadStep = value

    @property
    def restart_read_step_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartReadStepNumber() As short
                | 
                |     Sets or returns the step number of restart read requests. This is only
                |     valid if RestartReadOption is ABQ_STEP_NUMBER The value must be greater than or
                |     equal to 1 and less than total number of steps.
                | 
                |     Returns:
                |         The step number of restart read requests.
                | 
                |         Example:
                |             This example sets the step number for myJob job to
                |             2.
                | 
                |              myJob.RestartReadStepNumber = 2

        :rtype: int
        """

        return self.abq_job.RestartReadStepNumber

    @restart_read_step_number.setter
    def restart_read_step_number(self, value: int):
        """
        :param int value:
        """

        self.abq_job.RestartReadStepNumber = value

    @property
    def restart_read_step_selection_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartReadStepSelectionOption() As short
                | 
                |     Sets or returns the step selection option for restart
                |     read.
                | 
                |     Returns:
                |         The step selection option of restart read requests.
                | 
                |           
                |         Legal values:
                |          ABQ_STEP_OBJECT - Selects step object
                |          ABQ_STEP_NUMBER- Selects step by step number
                |          
                | 
                |         Example:
                |             This example sets the step selection option for myJob job to end of
                |             step.
                | 
                |              myJob.RestartReadStepSelectionOption = ABQ_STEP_OBJECT

        :return: enum abq_restart_read_step_sel_option
        :rtype: int
        """

        return self.abq_job.RestartReadStepSelectionOption

    @restart_read_step_selection_option.setter
    def restart_read_step_selection_option(self, value: int):
        """
        :param int value: enum abq_restart_read_step_sel_option
        """

        self.abq_job.RestartReadStepSelectionOption = value

    @property
    def restart_request_frequency(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartRequestFrequency() As short
                | 
                |     DEPRECATED - please use RestartRequestOption instead. Sets or returns the
                |     frequency of restart requests.
                | 
                |     Returns:
                |         The frequency of restart requests.
                | 
                |           
                |         Legal values:
                |          0 (None)
                |          1 (After each increment)
                |          999 (After the last increment in each step and after the last
                |          increment of the analysis)
                |          
                | 
                |         Example:
                |             This example sets the restart request frequency for myJob job to
                |             999.
                | 
                |              myJob.RestartRequestFrequency = 999

        :rtype: int
        """

        return self.abq_job.RestartRequestFrequency

    @restart_request_frequency.setter
    def restart_request_frequency(self, value: int):
        """
        :param int value:
        """

        self.abq_job.RestartRequestFrequency = value

    @property
    def restart_request_frequency_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartRequestFrequencyValue() As short
                | 
                |     Sets or returns the frequencey value of restart requests. This is only
                |     valid if RestartRequestOption is ABQ_RESTART_SPECINT. The value must be greater
                |     than 0.
                | 
                |     Returns:
                |         The frequency value of restart requests.
                | 
                |         Example:
                |             This example sets the restart request frequency value for myJob job
                |             to 10.
                | 
                |              myJob.RestartRequestFrequencyValue = 10

        :rtype: int
        """

        return self.abq_job.RestartRequestFrequencyValue

    @restart_request_frequency_value.setter
    def restart_request_frequency_value(self, value: int):
        """
        :param int value:
        """

        self.abq_job.RestartRequestFrequencyValue = value

    @property
    def restart_request_interval_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartRequestIntervalValue() As short
                | 
                |     Sets or returns the interval of restart requests. This is only valid if
                |     RestartRequestOption is ABQ_RESTART_NUMINT The value must be greater than
                |     0.
                | 
                |     Returns:
                |         The interval of restart requests.
                | 
                |         Example:
                |             This example sets the restart request interval for myJob job to
                |             10.
                | 
                |              myJob.RestartRequestIntervalValue = 10

        :rtype: int
        """

        return self.abq_job.RestartRequestIntervalValue

    @restart_request_interval_value.setter
    def restart_request_interval_value(self, value: int):
        """
        :param int value:
        """

        self.abq_job.RestartRequestIntervalValue = value

    @property
    def restart_request_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartRequestOption() As short
                | 
                |     Sets or returns the restart request option.
                | 
                |     Returns:
                |         The option of restart requests.
                |
                |         Legal values:
                |          ABQ_RESTART_NONE - No restart data.
                |          ABQ_RESTART_EVERYINC- Collect on every increment.
                |          ABQ_RESTART_SPECINC  - Used to define the frequency to collect the
                |          data.  
                |                             Used in conjunction with
                |                             RestartRequestFrequencyValue.
                |          ABQ_RESTART_NUMINT   - Used to define the interval to collect the
                |          data.
                |                             Used in conjunction with
                |                             RestartRequestIntervalValue.
                |          ABQ_RESTART_LASTINC  - Collect after the last increment in each step
                |          and 
                |                             after the last increment of the
                |                             analysis.
                |
                |         Example:
                |             This example sets the restart option for myJob job to every
                |             increment.
                | 
                |              myJob.RestartRequestOption = RESTART_EVERYINC

        :return: enum ABQ_RESTART_NONE
        :rtype: int
        """

        return self.abq_job.RestartRequestOption

    @restart_request_option.setter
    def restart_request_option(self, value: int):
        """
        :param int value: enum ABQ_RESTART_NONE
        """

        self.abq_job.RestartRequestOption = value

    @property
    def restart_request_overlay(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartRequestOverlay() As boolean
                | 
                |     Sets or returns the overlay option for the restart
                |     request.
                | 
                |     Returns:
                |         A boolean specifying whether the to use the overlay
                |         option.
                | 
                |         Example:
                |             This example sets the overlay option for the restart request for
                |             myJob job to True.
                | 
                |              myJob.RestartRequestOverlay = True

        :rtype: bool
        """

        return self.abq_job.RestartRequestOverlay

    @restart_request_overlay.setter
    def restart_request_overlay(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.RestartRequestOverlay = value

    @property
    def restart_request_time_marks(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RestartRequestTimeMarks() As boolean
                | 
                |     Sets or returns the time marks flag for restart requests. This is only
                |     valid if the RestartRequestOption is ABQ_RESTART_NUMINT.
                | 
                |     Returns:
                |         The time marks flag for restart requests.
                | 
                |         Example:
                |             This example sets the time marks flag for myJob job to
                |             10.
                | 
                |              myJob.RestartRequestTimeMarks = True

        :rtype: bool
        """

        return self.abq_job.RestartRequestTimeMarks

    @restart_request_time_marks.setter
    def restart_request_time_marks(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.RestartRequestTimeMarks = value

    @property
    def scratch(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Scratch() As CATBSTR
                | 
                |     Sets or returns or the path to the scratch directory.
                | 
                |     Returns:
                |         The path to the scratch directory.
                | 
                |         Example:
                |             This example sets the scratch directory for the myJob job to
                |             "D:\\Scratch".
                | 
                |              myJob.Scratch = "D:\\Scratch"

        :rtype: str
        """

        return self.abq_job.Scratch

    @scratch.setter
    def scratch(self, value: str):
        """
        :param str value:
        """

        self.abq_job.Scratch = value

    @property
    def source(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Source() As boolean
                | 
                |     Sets or returns the source for analysis.
                | 
                |     Returns:
                |         The source (model or input file).
                | 
                |         Example:
                |             This example sets the time marks flag for myJob job to From
                |             Model.
                | 
                |              myJob.Source = True

        :rtype: bool
        """

        return self.abq_job.Source

    @source.setter
    def source(self, value: bool):
        """
        :param bool value:
        """

        self.abq_job.Source = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Type() As Job_Type
                | 
                |     Returns or sets the job type.
                | 
                |     Returns:
                |         The job type.
                | 
                |           
                |         Legal values:
                |           ANALYSIS
                |           DATACHECK
                |           CONTINUE
                |           SYNTAXCHECK
                |           RESTART
                |          
                | 
                |         Example:
                |             This example sets the job type for the myJob job to
                |             ANALYSIS.
                | 
                |              myJob.Type = ANALYSIS

        :return: enum job_type
        :rtype: int
        """

        return self.abq_job.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value: enum job_type
        """

        self.abq_job.Type = value

    @property
    def user_subroutine(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserSubroutine() As CATBSTR
                | 
                |     Sets or returns the user subroutine file path.
                | 
                |     Returns:
                |         The user subroutine file path.
                | 
                |         Example:
                |             This example sets the user subroutine path for the myJob job to
                |             "D:/UserSub".
                | 
                |              myJob.UserSubroutine = "D:/UserSub"

        :rtype: str
        """

        return self.abq_job.UserSubroutine

    @user_subroutine.setter
    def user_subroutine(self, value: str):
        """
        :param str value:
        """

        self.abq_job.UserSubroutine = value

    def submit_job(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SubmitJob()
                | 
                |     Submits the job.

        :rtype: None
        """
        return self.abq_job.SubmitJob()

    def write_input_file(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub WriteInputFile()
                | 
                |     Writes the input file for the job.

        :rtype: None
        """
        return self.abq_job.WriteInputFile()

    def __repr__(self):
        return f'ABQJob(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_tabular_amplitude import ABQTabularAmplitude
from pycatia.abq_automation_interfaces.abq_temperature import ABQTemperature


class ABQTemperatureHistory(ABQTemperature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQTemperature
                |                         ABQTemperatureHistory
                | 
                | Represents an Abaqus temperature history object
                | (ABQTemperatureHistory).
                | Role: Access an Abaqus temperature history object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_temperature_history = com_object

    @property
    def activation_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActivationStatus() As boolean
                | 
                |     Sets or returns the activation status.
                | 
                |     Returns:
                |         A boolean specifying whether the feature is activated.

        :rtype: bool
        """

        return self.abq_temperature_history.ActivationStatus

    @activation_status.setter
    def activation_status(self, value: bool):
        """
        :param bool value:
        """

        self.abq_temperature_history.ActivationStatus = value

    @property
    def amplitude(self) -> ABQTabularAmplitude:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Amplitude() As ABQTabularAmplitude
                | 
                |     Sets or returns the amplitude of the temperature field.
                | 
                |     Example:
                |         This example retrieves the ABQTabularAmplitude
                |         abqAmplitude.
                | 
                |          Dim abqTemperature As ABQTemperature
                |          Dim abqAmplitude As ABQTabularAmplitude 
                |          Set abqAmplitude = abqTemperature.Amplitude

        :rtype: ABQTabularAmplitude
        """

        return ABQTabularAmplitude(self.abq_temperature_history.Amplitude)

    @amplitude.setter
    def amplitude(self, value: ABQTabularAmplitude):
        """
        :param ABQTabularAmplitude value:
        """

        self.abq_temperature_history.Amplitude = value

    @property
    def begin_step_num(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BeginStepNum() As short
                | 
                |     Sets or returns the step number at which to start reading the temperature
                |     data.

        :rtype: int
        """

        return self.abq_temperature_history.BeginStepNum

    @begin_step_num.setter
    def begin_step_num(self, value: int):
        """
        :param int value:
        """

        self.abq_temperature_history.BeginStepNum = value

    @property
    def end_step_num(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndStepNum() As short
                | 
                |     Sets or returns the step number at which to stop reading the temperature
                |     data.

        :rtype: int
        """

        return self.abq_temperature_history.EndStepNum

    @end_step_num.setter
    def end_step_num(self, value: int):
        """
        :param int value:
        """

        self.abq_temperature_history.EndStepNum = value

    @property
    def use_amplitude(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UseAmplitude() As boolean
                | 
                |     Sets or returns the UseAmplitude flag.
                | 
                |     Returns:
                |         A boolean specifying whether an amplitude will be
                |         used.

        :rtype: bool
        """

        return self.abq_temperature_history.UseAmplitude

    @use_amplitude.setter
    def use_amplitude(self, value: bool):
        """
        :param bool value:
        """

        self.abq_temperature_history.UseAmplitude = value

    def __repr__(self):
        return f'ABQTemperatureHistory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.general_knowledge_interfaces.expert_report_objects import ExpertReportObjects
from pycatia.general_knowledge_interfaces.expert_rule_base_component_runtime import ExpertRuleBaseComponentRuntime

if TYPE_CHECKING:
    from pycatia.general_knowledge_interfaces.expert_check import ExpertCheck


class ExpertCheckRuntime(ExpertRuleBaseComponentRuntime):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    GenKnowledgeInterfaces.ExpertRuleBaseComponentRuntime
                |                         ExpertCheckRuntime
                | 
                | Runtime part of a check.
                | The following example shows how to access the Check check1 from an existing
                | RuleSet RS1 of the RuleBase RB1.
                | 
                |  Dim CATDocs As Document
                |  Set CATDocs   = CATIA.Documents
                |  Dim partdoc As PartDocument
                |  Set partdoc   = CATDocs.Add("CATPart")
                |  Dim part As Part
                |  Set part      = partdoc.Part
                |  Dim relations As Relations
                |  Set relations = part.Relations
                |  Dim Rulebase As ExpertRuleBaseRuntime
                |  Set RuleBase  = relations.Item("RB1")
                |  Dim Ruleset As ExpertRuleSetRuntime
                |  Set RuleSet	 = RuleBase.RuleSet.ExpertRuleBaseComponentRuntimes.Item("RS1")
                |  Dim Check1 As ExpertCheckRuntime
                |  Set Check1	 = RuleSet.ExpertRuleBaseComponentRuntimes.Item("Check1")
                |  
                | 
                | See also:
                |     Relations, ExpertRuleBase
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_check_runtime = com_object

    @property
    def automatic_correct(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutomaticCorrect() As boolean
                | 
                |     Returns or sets the status of the automatic correction facility. When set
                |     to TRUE, the check automatically calls the user function defined by
                |     put_CorrectFunction when it fails.

        :rtype: bool
        """

        return self.expert_check_runtime.AutomaticCorrect

    @automatic_correct.setter
    def automatic_correct(self, value: bool):
        """
        :param bool value:
        """

        self.expert_check_runtime.AutomaticCorrect = value

    @property
    def check_edition(self) -> 'ExpertCheck':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CheckEdition() As ExpertCheck (Read Only)
                | 
                |     Returns the editable object corresponding to this check. Be careful that,
                |     according to your licence, or the type of check you're handling, you may not
                |     have the right to edit the check.
                | 
                |     Example:
                | 
                |          Dim aCheckEdition As ExpertCheck
                |          Set aCheckEdition = aCheckRuntime.CheckEdition
                | 
                |          If not(aCheckEdition is Nothing) Then
                |            CATIA.SystemService.Print aCheckEdition.Body
                |          End if

        :rtype: ExpertCheck
        """
        
        from pycatia.general_knowledge_interfaces.expert_check import ExpertCheck
        return ExpertCheck(self.expert_check_runtime.CheckEdition)

    @property
    def correct_function(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CorrectFunction() As CATBSTR
                | 
                |     Returns or sets the body to be called in order to correct the check.

        :rtype: str
        """

        return self.expert_check_runtime.CorrectFunction

    @correct_function.setter
    def correct_function(self, value: str):
        """
        :param str value:
        """

        self.expert_check_runtime.CorrectFunction = value

    @property
    def correct_function_comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CorrectFunctionComment() As CATBSTR
                | 
                |     Returns or sets the comment of the correct function of the check.

        :rtype: str
        """

        return self.expert_check_runtime.CorrectFunctionComment

    @correct_function_comment.setter
    def correct_function_comment(self, value: str):
        """
        :param str value:
        """

        self.expert_check_runtime.CorrectFunctionComment = value

    @property
    def correct_function_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CorrectFunctionType() As long
                | 
                |     Returns or sets the type of the body to be called in order to correct the
                |     check.
                | 
                |     1
                |         Visual Basic 
                |     2
                |         Comment 
                |     3
                |         Http 
                |     4
                |         User Function

        :rtype: int
        """

        return self.expert_check_runtime.CorrectFunctionType

    @correct_function_type.setter
    def correct_function_type(self, value: int):
        """
        :param int value:
        """

        self.expert_check_runtime.CorrectFunctionType = value

    @property
    def failures(self) -> ExpertReportObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Failures() As ExpertReportObjects (Read Only)
                | 
                |     Returns the list of the tuples that don't satisfy this check.

        :rtype: ExpertReportObjects
        """

        return ExpertReportObjects(self.expert_check_runtime.Failures)

    @property
    def help(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Help() As CATBSTR
                | 
                |     Returns or sets the contextual help of the check object.

        :rtype: str
        """

        return self.expert_check_runtime.Help

    @help.setter
    def help(self, value: str):
        """
        :param str value:
        """

        self.expert_check_runtime.Help = value

    @property
    def justification(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Justification() As CATBSTR
                | 
                |     Returns or sets the reason why the check was overridden.

        :rtype: str
        """

        return self.expert_check_runtime.Justification

    @justification.setter
    def justification(self, value: str):
        """
        :param str value:
        """

        self.expert_check_runtime.Justification = value

    @property
    def priority(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Priority() As double
                | 
                |     Returns or sets the priority of the check. The priority of expert checks
                |     indicates the order in which the checks are evaluated. Checks with the same
                |     priority are evaluated in the order of their creation.

        :rtype: float
        """

        return self.expert_check_runtime.Priority

    @priority.setter
    def priority(self, value: float):
        """
        :param float value:
        """

        self.expert_check_runtime.Priority = value

    @property
    def succeeds(self) -> ExpertReportObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Succeeds() As ExpertReportObjects (Read Only)
                | 
                |     Returns the list of the tuples that satisfy this check.

        :rtype: ExpertReportObjects
        """

        return ExpertReportObjects(self.expert_check_runtime.Succeeds)

    def correct(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Correct()
                | 
                |     Applies the "correction" function on failed elements.

        :rtype: None
        """
        return self.expert_check_runtime.Correct()

    def highlight(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Highlight()
                | 
                |     Highlights the Failures on the check.

        :rtype: None
        """
        return self.expert_check_runtime.Highlight()

    def status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Status() As long
                | 
                |     Returns the Status of the check.
                | 
                |     Example:
                | 
                |          Dim Check1 As ExpertCheck 
                |          Set Check1 = RuleSet.ExpertRuleBaseComponentRuntimes.Item("Check1")
                |          status = Check1.Status ()
                |          
                | 
                |     Returns:
                |         1=OK, 0=KO.

        :rtype: int
        """
        return self.expert_check_runtime.Status()

    def __repr__(self):
        return f'ExpertCheckRuntime(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeInverse(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeInverse
                | 
                | The Inverse feature : an Inverse is made up of a face to process and one Inverse parameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_inverse = com_object

    @property
    def element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Element() As Reference
                | 
                |     Role: To get the element inverted.
                | 
                |     Parameters:
                | 
                |         oElem
                |             Element inverted return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_inverse.Element)

    @element.setter
    def element(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_inverse.Element = reference_element.com_object

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Gets or sets the element's orientation.
                |     Orientation = 1 : the element is not inverted. = -1 : the element is inverted, =
                |      2 : the element can not be inverted. Orientation can not be set to 2.

        :rtype: int
        """

        return self.hybrid_shape_inverse.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_inverse.Orientation = value

    def __repr__(self):
        return f'HybridShapeInverse(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.system_interfaces.any_object import AnyObject


class SchAppClass(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppClass
                | 
                | Manage the class hierarchy of an application model.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_class = com_object

    def app_get_component_base_class(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppGetComponentBaseClass() As SchListOfBSTRs
                | 
                |     Provide the application class names for the base component
                |     classes.
                | 
                |     Parameters:
                | 
                |         oLBaseCompClasses
                |             Class names of application base component classes.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppClass
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.AppGetComponentBaseClass

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_app_class.AppGetComponentBaseClass())

    def app_get_group_base_class(self, o_group_class_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetGroupBaseClass(CATBSTR oGroupClassName)
                | 
                |     Provide the application class name for Schematic Group
                |     class.
                | 
                |     Parameters:
                | 
                |         oGroupClassName
                |             Class name of application class. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppClass
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppGetGroupBaseClassstrVar1

        :param str o_group_class_name:
        :rtype: None
        """
        return self.sch_app_class.AppGetGroupBaseClass(o_group_class_name)

    def app_get_route_base_class(self, o_route_class_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetRouteBaseClass(CATBSTR oRouteClassName)
                | 
                |     Provide the application class name for Schematic Route
                |     class.
                | 
                |     Parameters:
                | 
                |         oRouteClassName
                |             Class name of application class. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppClass
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppGetRouteBaseClassstrVar1

        :param str o_route_class_name:
        :rtype: None
        """
        return self.sch_app_class.AppGetRouteBaseClass(o_route_class_name)

    def app_get_zone_base_class(self, o_zone_class_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetZoneBaseClass(CATBSTR oZoneClassName)
                | 
                |     Provide the application class name for Schematic Zone
                |     class.
                | 
                |     Parameters:
                | 
                |         oZoneClassName
                |             Class name of application class. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppClass
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppGetZoneBaseClassstrVar1

        :param str o_zone_class_name:
        :rtype: None
        """
        return self.sch_app_class.AppGetZoneBaseClass(o_zone_class_name)

    def app_list_valid_route_types(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppListValidRouteTypes() As SchListOfBSTRs
                | 
                |     List the valid application route types allowed to be
                |     created.
                | 
                |     Parameters:
                | 
                |         oLValidRouteTypes
                |             A list of route class types allowed. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppClass
                |          Dim objArg1 As SchListOfBSTRs
                |           ...
                |          Set objArg1 = objThisIntf.AppListValidRouteTypes

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_app_class.AppListValidRouteTypes())

    def __repr__(self):
        return f'SchAppClass(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeNear(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeNear
                | 
                | The Near feature : an Near is made up of a face to process and one Near parameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_near = com_object

    @property
    def multiple_solution(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MultipleSolution() As Reference
                | 
                |     Role: To get_MultipleSolution on the object.
                | 
                |     Parameters:
                | 
                |         oMultipleSolution
                |             multiple element return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_near.MultipleSolution)

    @multiple_solution.setter
    def multiple_solution(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_near.MultipleSolution = reference.com_object

    @property
    def reference_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReferenceElement() As Reference
                | 
                |     Role: To get_ReferenceElement on the object.
                | 
                |     Parameters:
                | 
                |         oRefElem
                |             reference element return value for CATScript applications, with
                |             (IDLRETVAL) function type 
                | 
                |     See also:
                |         Reference 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_near.ReferenceElement)

    @reference_element.setter
    def reference_element(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_near.ReferenceElement = reference_element.com_object

    def __repr__(self):
        return f'HybridShapeNear(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_interaction import ABQInteraction
from pycatia.analysis_interfaces.analysis_entity import AnalysisEntity


class ABQFastenedConnectionEnhancement(ABQInteraction):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQInteraction
                |                         ABQFastenedConnectionEnhancement
                | 
                | This interface has been deprecated.
                | Please use ABQFastenedPair instead.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_fastened_connection_enhancement = com_object

    @property
    def adjust_slave_node(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AdjustSlaveNode() As boolean
                | 
                |     Sets or returns the adjust slave node flag.

        :rtype: bool
        """

        return self.abq_fastened_connection_enhancement.AdjustSlaveNode

    @adjust_slave_node.setter
    def adjust_slave_node(self, value: bool):
        """
        :param bool value:
        """

        self.abq_fastened_connection_enhancement.AdjustSlaveNode = value

    @property
    def connection_property(self) -> AnalysisEntity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectionProperty() As AnalysisEntity
                | 
                |     Sets or returns the connection property.

        :rtype: AnalysisEntity
        """

        return AnalysisEntity(self.abq_fastened_connection_enhancement.ConnectionProperty)

    @connection_property.setter
    def connection_property(self, value: AnalysisEntity):
        """
        :param AnalysisEntity value:
        """

        self.abq_fastened_connection_enhancement.ConnectionProperty = value

    @property
    def formulation_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FormulationOption() As FormulationOption_Type
                | 
                |     Sets or returns the formulation option.
                | 
                |     Returns:
                |         The formulation option.
                | 
                |         Legal values:
                | 
                |         SOLVERDEFAULT
                |         SURFACETOSURFACE
                |         NODETOSURFACE

        :return: enum formulation_option_type
        :rtype: int
        """

        return self.abq_fastened_connection_enhancement.FormulationOption

    @formulation_option.setter
    def formulation_option(self, value: int):
        """
        :param int value: enum formulation_option_type
        """

        self.abq_fastened_connection_enhancement.FormulationOption = value

    @property
    def include_shell_thickness(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IncludeShellThickness() As boolean
                | 
                |     Sets or returns the include shell element thickness flag.

        :rtype: bool
        """

        return self.abq_fastened_connection_enhancement.IncludeShellThickness

    @include_shell_thickness.setter
    def include_shell_thickness(self, value: bool):
        """
        :param bool value:
        """

        self.abq_fastened_connection_enhancement.IncludeShellThickness = value

    @property
    def invert_master_surface(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InvertMasterSurface() As boolean
                | 
                |     Sets or returns the invert master surface flag.

        :rtype: bool
        """

        return self.abq_fastened_connection_enhancement.InvertMasterSurface

    @invert_master_surface.setter
    def invert_master_surface(self, value: bool):
        """
        :param bool value:
        """

        self.abq_fastened_connection_enhancement.InvertMasterSurface = value

    @property
    def invert_slave_surface(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InvertSlaveSurface() As boolean
                | 
                |     Sets or returns the invert slave surface flag.

        :rtype: bool
        """

        return self.abq_fastened_connection_enhancement.InvertSlaveSurface

    @invert_slave_surface.setter
    def invert_slave_surface(self, value: bool):
        """
        :param bool value:
        """

        self.abq_fastened_connection_enhancement.InvertSlaveSurface = value

    @property
    def position_tolerance(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionTolerance() As PositionTolerance_Type
                | 
                |     Sets or returns the position tolerance.
                | 
                |     Returns:
                |         The position tolerance.
                | 
                |         Legal values:
                | 
                |         COMPUTED
                |         SPECIFIED

        :return: enum position_tolerance_type
        :rtype: int
        """

        return self.abq_fastened_connection_enhancement.PositionTolerance

    @position_tolerance.setter
    def position_tolerance(self, value: int):
        """
        :param int value: enum position_tolerance_type
        """

        self.abq_fastened_connection_enhancement.PositionTolerance = value

    @property
    def position_tolerance_val(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PositionToleranceVal() As double
                | 
                |     Sets or returns the position tolerance value

        :rtype: float
        """

        return self.abq_fastened_connection_enhancement.PositionToleranceVal

    @position_tolerance_val.setter
    def position_tolerance_val(self, value: float):
        """
        :param float value:
        """

        self.abq_fastened_connection_enhancement.PositionToleranceVal = value

    @property
    def swap_master_slave(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SwapMasterSlave() As boolean
                | 
                |     Sets or returns the swap master/slave surface flag.

        :rtype: bool
        """

        return self.abq_fastened_connection_enhancement.SwapMasterSlave

    @swap_master_slave.setter
    def swap_master_slave(self, value: bool):
        """
        :param bool value:
        """

        self.abq_fastened_connection_enhancement.SwapMasterSlave = value

    def __repr__(self):
        return f'ABQFastenedConnectionEnhancement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingResourceFactory(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingResourceFactory
                | 
                | Interface to create manufacturing resources.
                | Role: This interface offers services to create manufacturing
                | resources
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_resource_factory = com_object

    def create_resource(self, i_type: str, i_add_list: bool) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateResource(CATBSTR iType,
                | boolean iAddList) As AnyObject
                | 
                |     This method is used to create a new manufacturing
                |     resource.
                | 
                |     Parameters:
                | 
                |         iType
                |             The type of the resource to create. 
                |         iAddList
                |             Flag to add the resource into the resource List. 
                |         oResource
                |             Handler on the newly created resource of given type.
                |             
                | 
                |     See also:
                |         DELIMAMfgResource

        :param str i_type:
        :param bool i_add_list:
        :rtype: AnyObject
        """
        return AnyObject(self.manufacturing_resource_factory.CreateResource(i_type, i_add_list))

    def __repr__(self):
        return f'ManufacturingResourceFactory(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.assembly_interfaces.assembly_feature import AssemblyFeature
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product


class AssemblySplit(AssemblyFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAssemblyInterfaces.AssemblyFeature
                |                         AssemblySplit
                | 
                | Represents the AssemblySplit object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_split = com_object

    @property
    def splitting_component(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplittingComponent() As Product (Read Only)
                | 
                |     Returns the component containing the splitting element.
                | 
                |     Example:
                |         The following example retrieves in sptComponent the splitting component
                |         containing the splitting element of the assembly split
                |         assemblySplit:
                | 
                |          Dim sptComponent As Product
                |          Set sptComponent = assemblySplit.SplittingComponent

        :rtype: Product
        """

        return Product(self.assembly_split.SplittingComponent)

    @property
    def splitting_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplittingElement() As Reference (Read Only)
                | 
                |     Returns the splitting element.
                | 
                |     Example:
                |         The following example retrieves in sptElement the splitting element of
                |         the assembly split assemblySplit:
                | 
                |          Dim sptElement As Reference
                |          Set sptElement = assemblySplit.SplittingElement

        :rtype: Reference
        """

        return Reference(self.assembly_split.SplittingElement)

    @property
    def splitting_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplittingSide() As CatSplitSide
                | 
                |     Returns or sets the splitting side. The splitting side is the side of the
                |     split object kept after the split, with respect to the splitting element. A
                |     positive side refers to the split object side shown by the splitting element
                |     normal vector.
                | 
                |     Example:
                |         The following example returns in sptSide the splitting side of the
                |         assembly split assemblySplit, and then sets it to
                |         catPositiveSide:
                | 
                |          Set sptSide = assemblySplit.SplittingSide
                |          assemblySplit.SplittingSide = catPositiveSide

        :return: enum cat_split_side
        :rtype: int
        """

        return self.assembly_split.SplittingSide

    @splitting_side.setter
    def splitting_side(self, value: int):
        """
        :param int value: enum cat_split_side
        """

        self.assembly_split.SplittingSide = value

    def modify_splitting_element(self, i_splitting_element: Reference, i_splitting_elem_comp: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ModifySplittingElement(Reference iSplittingElement,
                | Product iSplittingElemComp)
                | 
                |     Replaces the splitting element by a new one.
                | 
                |     Parameters:
                | 
                |         iSplittingElement
                |             The new face or plane that will split the current body
                |             
                |         iSplittingElemComp
                |             The component that contains the new splitting element
                |             
                | 
                |     Example:
                |         The following example replaces the existing splitting element of the
                |         assembly split assemblySplit by sptElem contained in the sptComponent splitting
                |         component
                | 
                |          assemblySplit.ModifySplittingElement(sptElem, _
                |                                               sptComponent)

        :param Reference i_splitting_element:
        :param Product i_splitting_elem_comp:
        :rtype: None
        """
        return self.assembly_split.ModifySplittingElement(
            i_splitting_element.com_object,
            i_splitting_elem_comp.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'modify_splitting_element'
        # # vba_code = """
        # # Public Function modify_splitting_element(assembly_split)
        # #     Dim iSplittingElement (2)
        # #     assembly_split.ModifySplittingElement iSplittingElement
        # #     modify_splitting_element = iSplittingElement
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblySplit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.walk_activity import WalkActivity


class CollisionFreeWalk(WalkActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             DNBHumanSimInterfaces.WalkActivity
                |                                 CollisionFreeWalk
                | 
                | Interface representing Collision free walk activity
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.collision_free_walk = com_object

    @property
    def collision_clearance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CollisionClearance() As double
                | 
                |     Returns and sets the value for 'collision clearance' in a collision free
                |     walk.
                |     Role: Returns and sets the value of 'colllision clearance' from a collision
                |     free walk Activity
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: float
        """

        return self.collision_free_walk.CollisionClearance

    @collision_clearance.setter
    def collision_clearance(self, value: float):
        """
        :param float value:
        """

        self.collision_free_walk.CollisionClearance = value

    @property
    def search_intensity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SearchIntensity() As HTSSearchIntensity
                | 
                |     Returns and sets the value for 'Search Intensity' in a collision free walk.
                |     Refer DNBIAHumanSimDefs for setting the HTSSearchIntensity option
                |     Role: Returns and sets the value of 'Search Intensity' from a collision
                |     free walk Activity
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum hts_search_intensity
        :rtype: int
        """

        return self.collision_free_walk.SearchIntensity

    @search_intensity.setter
    def search_intensity(self, value: int):
        """
        :param int value: enum hts_search_intensity
        """

        self.collision_free_walk.SearchIntensity = value

    def __repr__(self):
        return f'CollisionFreeWalk(name="{self.name}")'
